@@ -17,9 +17,9 @@
 from minio import Minio
 
 client = Minio(
-    endpoint="play.min.io",
+    "play.min.io",
     access_key="Q3AM3UQ867SPQQA43P2F",
     secret_key="zuf+tfteSlswRu7BJ86wekitnifILbZam1KYY3TG",
 )
 
-tags = client.get_object_tags(bucket_name="my-bucket", object_name="my-object")
+tags = client.get_object_tags("my-bucket", "my-object")
