@@ -18,7 +18,7 @@ from minio import Minio
 from minio.commonconfig import Tags
 
 client = Minio(
-    endpoint="play.min.io",
+    "play.min.io",
     access_key="Q3AM3UQ867SPQQA43P2F",
     secret_key="zuf+tfteSlswRu7BJ86wekitnifILbZam1KYY3TG",
 )
@@ -26,8 +26,4 @@ client = Minio(
 tags = Tags.new_object_tags()
 tags["Project"] = "Project One"
 tags["User"] = "jsmith"
-client.set_object_tags(
-    bucket_name="my-bucket",
-    object_name="my-object",
-    tags=tags,
-)
+client.set_object_tags("my-bucket", "my-object", tags)
