@@ -20,8 +20,6 @@ from datetime import datetime, timezone
 from unittest import TestCase
 from urllib.parse import urlsplit, urlunsplit
 
-from urllib3._collections import HTTPHeaderDict
-
 from minio import Minio
 from minio.credentials import Credentials
 from minio.helpers import queryencode, quote, sha256_hash
@@ -42,16 +40,12 @@ class CanonicalRequestTest(TestCase):
                                   empty_hash, 'x-amz-date:dateString',
                                   '', ';'.join(expected_signed_headers),
                                   empty_hash]
-        headers_to_sign = HTTPHeaderDict(
-            {'x-amz-date': 'dateString', 'x-amz-content-sha256': empty_hash},
-        )
+        headers_to_sign = {'x-amz-date': 'dateString',
+                           'x-amz-content-sha256': empty_hash}
 
         expected_request = sha256_hash('\n'.join(expected_request_array))
         actual_request = _get_canonical_request_hash(
-            method="PUT",
-            url=url,
-            headers=headers_to_sign,
-            content_sha256=empty_hash,
+            "PUT", url, headers_to_sign, empty_hash,
         )
         self.assertEqual(expected_request, actual_request[0])
 
@@ -66,14 +60,10 @@ class CanonicalRequestTest(TestCase):
 
         expected_request = sha256_hash('\n'.join(expected_request_array))
 
-        headers_to_sign = HTTPHeaderDict(
-            {'x-amz-date': 'dateString', 'x-amz-content-sha256': empty_hash},
-        )
+        headers_to_sign = {'x-amz-date': 'dateString',
+                           'x-amz-content-sha256': empty_hash}
         actual_request = _get_canonical_request_hash(
-            method="PUT",
-            url=url,
-            headers=headers_to_sign,
-            content_sha256=empty_hash,
+            "PUT", url, headers_to_sign, empty_hash,
         )
         self.assertEqual(expected_request, actual_request[0])
 
@@ -143,19 +133,15 @@ class PresignURLTest(TestCase):
 
 class SignV4Test(TestCase):
     def test_signv4(self):
-        client = Minio(
-            endpoint="localhost:9000",
-            access_key="minio",
-            secret_key="minio123",
-            secure=False,
-        )
+        client = Minio("localhost:9000", access_key="minio",
+                       secret_key="minio123", secure=False)
         creds = client._provider.retrieve()
-        headers = HTTPHeaderDict({
+        headers = {
             'Host': 'localhost:9000',
             'x-amz-content-sha256':
             'e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855',
             'x-amz-date': '20150620T010203Z',
-        })
+        }
         url = client._base_url.build(
             method="PUT",
             region="us-east-1",
